package demo;

import java.io.File;

import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.JDialog;
import javax.swing.JFileChooser;
import javax.swing.filechooser.FileFilter;
import javax.swing.UIManager;

import com.japisoft.resourcebrowser.FileResourceView;
import com.japisoft.zipbrowser.ZIPBrowser;

/**
 * Here a simple demo for browsing a zip or an archive
 * @author (c) 2004 JAPISoft / http://www.japisoft.com
 * @version 1.0
 * */
public class ZipBrowserDemo {

	public static void main(String[] args) {
		try {
			UIManager.setLookAndFeel( UIManager.getSystemLookAndFeelClassName() );
		} catch( Exception exc ) {
		}
		
		JFileChooser chooser = new JFileChooser();
		chooser.setFileFilter(
				new FileFilter() {
					public boolean accept(File f) {
						return f.isDirectory() || 
							f.getName().endsWith( ".zip" ) ||
								f.getName().endsWith( ".jar" );
					}
					
					public String getDescription() {
						return "ZIP (*.zip), JAR (*.jar)";
					}
					
				} );

		chooser.setDialogTitle( "Choose a ZIP or a JAR file" );

		if ( chooser.showOpenDialog( null ) == JFileChooser.APPROVE_OPTION ) {
			File f = chooser.getSelectedFile();
			JDialog dialog = new JDialog();
			dialog.setModal( true );
			dialog.setTitle( "Browse " + f );

			ZIPBrowser browser;
			
			dialog.getContentPane().add( browser = new ZIPBrowser( f ) );
			dialog.setSize( 500, 550 );
			
			// We create a custom view for files
			browser.setFileResourceView( new FileUIDelegate() );
			
			dialog.setVisible( true );

			// It will close the browsed file as it is in a modal state
			dialog.dispose();
		}

	}

	/** We create a delegate for rendering each file. Note that this is not
	 * required and this is only for demonstration */
	static class FileUIDelegate implements FileResourceView {
		
		ImageIcon icon = new ImageIcon( ClassLoader.getSystemClassLoader().getResource( "images/document.png" ) );
		
		public Icon getIcon(String fileName) {
			
			// We don't want icons for java class files
			if ( fileName.endsWith( ".class" ) )
				return null;
			
			return icon;
		}

		// We maintain the same name
		public String getName(String fileName) {
			return fileName;
		}

	}

}
